@@ -14,7 +14,7 @@ test_that("insert post space - single grouping variable",{
   )
 
   expect_equal(
-    apply_row_grp_struct(df, sample_grp_plan$struct_ls, vars(grp1), sym("label")),
+    apply_row_grp_struct(df, sample_grp_plan$struct_list, vars(grp1), sym("label")),
     tibble::tribble(
       ~grp1,~label, ~trtA,      ~trtB,      ~trtC,
       "A",  "1",  "xx (xx%)", "xx (xx%)", "xx (xx%)",
@@ -33,7 +33,7 @@ test_that("insert post space - single grouping variable",{
   )
 
   expect_equal(
-    apply_row_grp_struct(df, sample_grp_plan$struct_ls, vars(grp1), sym("label")),
+    apply_row_grp_struct(df, sample_grp_plan$struct_list, vars(grp1), sym("label")),
     tibble::tribble(
       ~grp1, ~label, ~trtA,      ~trtB,       ~trtC,
       "A", "1", "xx (xx%)", "xx (xx%)", "xx (xx%)",
@@ -65,7 +65,7 @@ test_that("insert post space - two grouping variables",{
   )
 
   expect_equal(
-    apply_row_grp_struct(df, sample_grp_plan$struct_ls, vars(grp1, grp2), label = sym("label")),
+    apply_row_grp_struct(df, sample_grp_plan$struct_list, vars(grp1, grp2), label = sym("label")),
     tibble::tribble(
       ~grp1, ~grp2, ~label,   ~trtA,       ~trtB,     ~trtC,
       "A",  "a",   "1", "xx (xx%)" ,"xx (xx%)", "xx (xx%)",
@@ -104,7 +104,7 @@ test_that("insert mix - single grouping variable",{
   )
 
   expect_equal(
-    apply_row_grp_struct(df, sample_grp_plan$struct_ls, vars(grp1)),
+    apply_row_grp_struct(df, sample_grp_plan$struct_list, vars(grp1)),
     tibble::tribble(
       ~grp1, ~trtA,      ~trtB,      ~trtC,
       "A",  "xx (xx%)", "xx (xx%)",  "xx (xx%)",
@@ -137,7 +137,7 @@ test_that("insert post space after specific value",{
   )
 
   expect_equal(
-    apply_row_grp_struct(df, sample_grp_plan$struct_ls, vars(grp1, grp2), label = sym("label")),
+    apply_row_grp_struct(df, sample_grp_plan$struct_list, vars(grp1, grp2), label = sym("label")),
     tibble::tribble(
       ~grp1,  ~grp2, ~label,   ~trtA,       ~trtB,     ~trtC,
       "A",     "a", "1",   "xx (xx%)", "xx (xx%)", "xx (xx%)",
@@ -173,7 +173,7 @@ test_that("overlapping row_grp_structures - prefers latest",{
   )
 
   expect_equal(
-    apply_row_grp_struct(df, sample_grp_plan$struct_ls, vars(grp1, grp2), label = sym("label")),
+    apply_row_grp_struct(df, sample_grp_plan$struct_list, vars(grp1, grp2), label = sym("label")),
     tibble::tribble(
       ~grp1,  ~grp2, ~label,   ~trtA,       ~trtB,     ~trtC,
       "A",     "a", "1",   "xx (xx%)", "xx (xx%)", "xx (xx%)",
@@ -208,7 +208,7 @@ test_that("no post space added if NULL",{
   )
 
   expect_equal(
-    apply_row_grp_struct(df, sample_grp_plan$struct_ls, vars(grp1)),
+    apply_row_grp_struct(df, sample_grp_plan$struct_list, vars(grp1)),
     tibble::tribble(
       ~grp1, ~trtA,      ~trtB,      ~trtC,
       "A",  "xx (xx%)", "xx (xx%)", "xx (xx%)",
@@ -235,7 +235,7 @@ test_that("post space is truncated to data width",{
   )
 
   expect_equal(
-    apply_row_grp_struct(df, sample_grp_plan$struct_ls, vars(grp1)),
+    apply_row_grp_struct(df, sample_grp_plan$struct_list, vars(grp1)),
     tibble::tribble(
       ~grp1, ~trtA,      ~trtB,      ~trtC,
       "A",  "xx (xx%)", "xx (xx%)",  "xx (xx%)",
@@ -248,6 +248,34 @@ test_that("post space is truncated to data width",{
       "D",  "--------", "--------",  "--------"))
 })
 
+test_that("post space works when data contains NAs",{
+
+  df <- tibble(
+    grp1 = c("A","B","C","D"),
+    trtA = rep("xx (xx%)", 4),
+    trtB = rep("xx (xx%)", 4),
+    trtC = rep("xx (xx%)", 4),
+    other = c("a","a","b", NA)
+  )
+
+  sample_grp_plan <- row_grp_plan(
+    row_grp_structure(group_val = ".default", element_block(post_space ="----------------------")),
+    label_loc =element_row_grp_loc(location = "spanning")
+  )
+
+  expect_equal(
+    apply_row_grp_struct(df, sample_grp_plan$struct_list, vars(grp1)),
+    tibble::tribble(
+      ~grp1, ~trtA,      ~trtB,      ~trtC,      ~other,
+      "A",  "xx (xx%)", "xx (xx%)",  "xx (xx%)", "a",
+      "A",  "--------", "--------",  "--------", "-",
+      "B",  "xx (xx%)", "xx (xx%)",  "xx (xx%)", "a",
+      "B",  "--------", "--------",  "--------", "-",
+      "C",  "xx (xx%)", "xx (xx%)",  "xx (xx%)", "b",
+      "C",  "--------", "--------",  "--------", "-",
+      "D",  "xx (xx%)", "xx (xx%)",  "xx (xx%)", NA,
+      "D",  "--------", "--------",  "--------", "-"))
+})
 
 test_that("Check combine_group_cols with a single group", {
 
@@ -392,7 +420,7 @@ test_that("Check apply_row_grp_* w/ list-columns (in case of incomplete body_pla
   expect_equal(auto_test_listcols, man_test_listcols)
 
 
-  auto_test_listcols <- apply_row_grp_struct(mock_multi_grp, sample_grp_plan$struct_ls,group = vars(grp1, grp2), label = sym("my_label"))
+  auto_test_listcols <- apply_row_grp_struct(mock_multi_grp, sample_grp_plan$struct_list,group = vars(grp1, grp2), label = sym("my_label"))
 
   man_test_listcols <- tibble::tribble(
     ~grp1,    ~grp2,   ~my_label,      ~trtA,     ~trtB,     ~trtC,
