@@ -549,3 +549,179 @@ test_that("Test big n with footnotes", {
 
 
 })
+
+test_that("big Ns vary by page",{
+
+  data <- tibble(Group = rep(c("Age (y)", "Sex"), c(3, 3)),
+                 Label = rep("n",6),
+                 Column = rep(c("Placebo", "Treatment", "Total"), times = 2),
+                 Param = rep("n",6),
+                 Value = c(12, 14, 31, 20, 32, 18)
+  ) %>%
+    mutate(ord1 = if_else(Group == "Age (y)", 1, 2))
+
+  big_ns <- data %>%
+    summarise(.by = c(Group, Column), Value = sum(Value)) %>%
+    mutate(Param = "big_N")
+  data <- bind_rows(data, big_ns)
+
+  mytfrmt <- tfrmt(
+    group = Group,
+    label = Label,
+    column = Column,
+    value = Value,
+    param = Param,
+    sorting_cols = ord1,
+    body_plan = body_plan(
+      frmt_structure(group_val = ".default", label_val = ".default", frmt("xx"))
+    ),
+    col_plan = col_plan(everything(), -starts_with("ord"), "Total"),
+    row_grp_plan = row_grp_plan(
+      row_grp_structure(group_val = ".default", element_block(post_space = " "))
+    ),
+    page_plan = page_plan(
+      page_structure(group_val = ".default")
+    ),
+    big_n = big_n_structure(param_val = c("big_N"), by_page = TRUE)
+  )
+
+  auto <- mytfrmt %>%
+    apply_tfrmt(.data = data, tfrmt = ., mock = FALSE)
+
+  auto_names <- map(auto, names)
+  man_names <- list(
+    c("Label", "Placebo\nN = 12", "Treatment\nN = 14", "Total\nN = 31", "..tfrmt_row_grp_lbl"),
+    c("Label", "Placebo\nN = 20", "Treatment\nN = 32", "Total\nN = 18", "..tfrmt_row_grp_lbl")
+  )
+  expect_equal(auto_names, man_names)
+
+
+
+})
+
+test_that("big Ns constant by page",{
+
+  # big Ns are constant by page
+  data <- tibble(Group = rep(c("Age (y)", "Sex"), c(3, 3)),
+                 Label = rep("n",6),
+                 Column = rep(c("Placebo", "Treatment", "Total"), times = 2),
+                 Param = rep("n",6),
+                 Value = c(12, 14, 31, 20, 32, 18)
+  ) %>%
+    mutate(ord1 = if_else(Group == "Age (y)", 1, 2))
+  big_ns <- data %>%
+    summarise(.by = c( Column), Value = sum(Value)) %>%
+    mutate(Param = "big_N")
+  data <- bind_rows(data, big_ns)
+
+  mytfrmt <- tfrmt(
+    group = Group,
+    label = Label,
+    column = Column,
+    value = Value,
+    param = Param,
+    sorting_cols = ord1,
+    body_plan = body_plan(
+      frmt_structure(group_val = ".default", label_val = ".default", frmt("xx"))
+    ),
+    col_plan = col_plan(everything(), -starts_with("ord"), "Total"),
+    row_grp_plan = row_grp_plan(
+      row_grp_structure(group_val = ".default", element_block(post_space = " "))
+    ),
+    page_plan = page_plan(
+      page_structure(group_val = ".default")
+    ),
+    big_n = big_n_structure(param_val = c("big_N"), by_page = FALSE)
+  )
+
+  auto <- mytfrmt %>%
+    apply_tfrmt(.data = data, tfrmt = ., mock = FALSE)
+  expect_equal(
+    map(auto, names),
+    list(
+      c("Label","Placebo\nN = 32","Treatment\nN = 46","Total\nN = 49","..tfrmt_row_grp_lbl"),
+      c("Label","Placebo\nN = 32","Treatment\nN = 46","Total\nN = 49","..tfrmt_row_grp_lbl")
+    )
+  )
+
+  # big Ns constant by page but by_page=TRUE in the big_n_structure gives message
+  mytfrmt <- tfrmt(
+    group = Group,
+    label = Label,
+    column = Column,
+    value = Value,
+    param = Param,
+    sorting_cols = ord1,
+    body_plan = body_plan(
+      frmt_structure(group_val = ".default", label_val = ".default", frmt("xx"))
+    ),
+    col_plan = col_plan(everything(), -starts_with("ord"), "Total"),
+    row_grp_plan = row_grp_plan(
+      row_grp_structure(group_val = ".default", element_block(post_space = " "))
+    ),
+    page_plan = page_plan(
+      page_structure(group_val = ".default")
+    ),
+    big_n = big_n_structure(param_val = c("big_N"), by_page = TRUE)
+  )
+
+  expect_message(
+    auto <- mytfrmt %>%
+      apply_tfrmt(.data = data, tfrmt = ., mock = FALSE),
+    "Mismatch between big Ns and page_plan. For varying big N's by page (`by_page` = TRUE in `big_n_structure`), data must contain 1 big N value per unique grouping variable/value set to \".default\" in `page_plan`",
+    fixed = TRUE
+  )
+
+
+  expect_equal(
+    map(auto, names),
+    list(
+      c("Label","Placebo\nN = 32","Treatment\nN = 46","Total\nN = 49","..tfrmt_row_grp_lbl"),
+      c("Label","Placebo\nN = 32","Treatment\nN = 46","Total\nN = 49","..tfrmt_row_grp_lbl")
+    )
+  )
+
+  # too many big Ns provided with by_page = FALSE
+
+  data <- tibble(Group = rep(c("Age (y)", "Sex"), c(3, 3)),
+                 Label = rep("n",6),
+                 Column = rep(c("Placebo", "Treatment", "Total"), times = 2),
+                 Param = rep("n",6),
+                 Value = c(12, 14, 31, 20, 32, 18)
+  ) %>%
+    mutate(ord1 = if_else(Group == "Age (y)", 1, 2))
+
+  big_ns <- data %>%
+    summarise(.by = c(Group, Column), Value = sum(Value)) %>%
+    mutate(Param = "big_N")
+  data <- bind_rows(data, big_ns)
+
+  mytfrmt <- tfrmt(
+    group = Group,
+    label = Label,
+    column = Column,
+    value = Value,
+    param = Param,
+    sorting_cols = ord1,
+    body_plan = body_plan(
+      frmt_structure(group_val = ".default", label_val = ".default", frmt("xx"))
+    ),
+    col_plan = col_plan(everything(), -starts_with("ord"), "Total"),
+    row_grp_plan = row_grp_plan(
+      row_grp_structure(group_val = ".default", element_block(post_space = " "))
+    ),
+    page_plan = page_plan(
+      page_structure(group_val = ".default")
+    ),
+    big_n = big_n_structure(param_val = c("big_N"), by_page = FALSE)
+  )
+
+  expect_warning(
+    auto <- mytfrmt %>%
+      apply_tfrmt(.data = data, tfrmt = ., mock = FALSE)  ,
+    paste(c("The following columns have multiple Big N's associated with them :",
+          "c(\"Placebo\", \"Total\", \"Treatment\")"), collapse = "\n"),
+      fixed = TRUE
+  )
+
+})
